==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/CheckboxChangeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CheckboxChangeEventArgsDescription } from "./CheckboxChangeEventArgsDescription";
/**
 * @hidden
 */
export let CheckboxChangeEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class CheckboxChangeEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (CheckboxChangeEventArgsDescriptionMetadata.a == null) {
                CheckboxChangeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CheckboxChangeEventArgsDescriptionMetadata.c(CheckboxChangeEventArgsDescriptionMetadata.a);
            }
            if (a.j(CheckboxChangeEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(CheckboxChangeEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("IsChecked", "Boolean");
            a.item("IsIndeterminate", "Boolean");
        }
        static d(a) {
            CheckboxChangeEventArgsDescriptionMetadata.b(a);
            a.aa("CheckboxChangeEventArgs", () => new CheckboxChangeEventArgsDescription());
            a.z("CheckboxChangeEventArgs", CheckboxChangeEventArgsDescriptionMetadata.a);
        }
    }
    CheckboxChangeEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(CheckboxChangeEventArgsDescriptionMetadata, 'CheckboxChangeEventArgsDescriptionMetadata');
    CheckboxChangeEventArgsDescriptionMetadata.a = null;
    return CheckboxChangeEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/CheckboxChangeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CheckboxChangeEventArgsDescription } from "./CheckboxChangeEventArgsDescription";
/**
 * @hidden
 */
export let CheckboxChangeEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class CheckboxChangeEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (CheckboxChangeEventArgsDescriptionMetadata.a == null) {
                CheckboxChangeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CheckboxChangeEventArgsDescriptionMetadata.c(CheckboxChangeEventArgsDescriptionMetadata.a);
            }
            if (a.k(CheckboxChangeEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(CheckboxChangeEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("IsChecked", "Boolean");
            a.item("IsIndeterminate", "Boolean");
        }
        static d(a) {
            CheckboxChangeEventArgsDescriptionMetadata.b(a);
            a.ac("CheckboxChangeEventArgs", () => new CheckboxChangeEventArgsDescription());
            a.ab("CheckboxChangeEventArgs", CheckboxChangeEventArgsDescriptionMetadata.a);
        }
    }
    CheckboxChangeEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(CheckboxChangeEventArgsDescriptionMetadata, 'CheckboxChangeEventArgsDescriptionMetadata');
    CheckboxChangeEventArgsDescriptionMetadata.a = null;
    return CheckboxChangeEventArgsDescriptionMetadata;
})();
